==> msgspec_schemaorg-0.1.0-py3-none-any.whl: msgspec_schemaorg/models/creativework/SpecialAnnouncement.py <==
from __future__ import annotations
from msgspec import Struct, field
from msgspec_schemaorg.utils import parse_iso8601
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from msgspec_schemaorg.models.action.Action import Action
    from msgspec_schemaorg.models.creativework.AudioObject import AudioObject
    from msgspec_schemaorg.models.creativework.Claim import Claim
    from msgspec_schemaorg.models.creativework.Clip import Clip
    from msgspec_schemaorg.models.creativework.Comment import Comment
    from msgspec_schemaorg.models.creativework.CorrectionComment import CorrectionComment
    from msgspec_schemaorg.models.creativework.CreativeWork import CreativeWork
    from msgspec_schemaorg.models.creativework.DataFeed import DataFeed
    from msgspec_schemaorg.models.creativework.Dataset import Dataset
    from msgspec_schemaorg.models.creativework.ImageObject import ImageObject
    from msgspec_schemaorg.models.creativework.MediaObject import MediaObject
    from msgspec_schemaorg.models.creativework.MusicRecording import MusicRecording
    from msgspec_schemaorg.models.creativework.Review import Review
    from msgspec_schemaorg.models.creativework.TextObject import TextObject
    from msgspec_schemaorg.models.creativework.VideoObject import VideoObject
    from msgspec_schemaorg.models.creativework.WebContent import WebContent
    from msgspec_schemaorg.models.creativework.WebPage import WebPage
    from msgspec_schemaorg.models.event.Event import Event
    from msgspec_schemaorg.models.event.PublicationEvent import PublicationEvent
    from msgspec_schemaorg.models.intangible.AggregateRating import AggregateRating
    from msgspec_schemaorg.models.intangible.AlignmentObject import AlignmentObject
    from msgspec_schemaorg.models.intangible.Audience import Audience
    from msgspec_schemaorg.models.intangible.CategoryCode import CategoryCode
    from msgspec_schemaorg.models.intangible.DefinedTerm import DefinedTerm
    from msgspec_schemaorg.models.intangible.Demand import Demand
    from msgspec_schemaorg.models.intangible.Duration import Duration
    from msgspec_schemaorg.models.intangible.GovernmentService import GovernmentService
    from msgspec_schemaorg.models.intangible.Grant import Grant
    from msgspec_schemaorg.models.intangible.IPTCDigitalSourceEnumeration import IPTCDigitalSourceEnumeration
    from msgspec_schemaorg.models.intangible.InteractionCounter import InteractionCounter
    from msgspec_schemaorg.models.intangible.ItemList import ItemList
    from msgspec_schemaorg.models.intangible.Language import Language
    from msgspec_schemaorg.models.intangible.Observation import Observation
    from msgspec_schemaorg.models.intangible.Offer import Offer
    from msgspec_schemaorg.models.intangible.PhysicalActivityCategory import PhysicalActivityCategory
    from msgspec_schemaorg.models.intangible.PropertyValue import PropertyValue
    from msgspec_schemaorg.models.intangible.QuantitativeValue import QuantitativeValue
    from msgspec_schemaorg.models.intangible.Rating import Rating
    from msgspec_schemaorg.models.intangible.SizeSpecification import SizeSpecification
    from msgspec_schemaorg.models.organization.LocalBusiness import LocalBusiness
    from msgspec_schemaorg.models.organization.Organization import Organization
    from msgspec_schemaorg.models.person.Person import Person
    from msgspec_schemaorg.models.place.CivicStructure import CivicStructure
    from msgspec_schemaorg.models.place.Country import Country
    from msgspec_schemaorg.models.place.Place import Place
    from msgspec_schemaorg.models.product.Product import Product
    from msgspec_schemaorg.models.thing.Thing import Thing
from datetime import date, datetime


class SpecialAnnouncement(Struct, frozen=True):
    """A SpecialAnnouncement combines a simple date-stamped textual information update
      with contextualized Web links and other structured data.  It represents an information update made by a
      locally-oriented organization, for example schools, pharmacies, healthcare providers,  community groups, police,
      local government.

For work in progress guidelines on Coronavirus-related markup see [this doc](https://docs.google.com/document/d/14ikaGCKxo50rRM7nvKSlbUpjyIk2WMQd3IkB1lItlrM/edit#).

The motivating scenario for SpecialAnnouncement is the [Coronavirus pandemic](https://en.wikipedia.org/wiki/2019%E2%80%9320_coronavirus_pandemic), and the initial vocabulary is oriented to this urgent situation. Schema.org
expect to improve the markup iteratively as it is deployed and as feedback emerges from use. In addition to our
usual [Github entry](https://github.com/schemaorg/schemaorg/issues/2490), feedback comments can also be provided in [this document](https://docs.google.com/document/d/1fpdFFxk8s87CWwACs53SGkYv3aafSxz_DTtOQxMrBJQ/edit#).


While this schema is designed to communicate urgent crisis-related information, it is not the same as an emergency warning technology like [CAP](https://en.wikipedia.org/wiki/Common_Alerting_Protocol), although there may be overlaps. The intent is to cover
the kinds of everyday practical information being posted to existing websites during an emergency situation.

Several kinds of information can be provided:

We encourage the provision of "name", "text", "datePosted", "expires" (if appropriate), "category" and
"url" as a simple baseline. It is important to provide a value for "category" where possible, most ideally as a well known
URL from Wikipedia or Wikidata. In the case of the 2019-2020 Coronavirus pandemic, this should be "https://en.wikipedia.org/w/index.php?title=2019-20\\_coronavirus\\_pandemic" or "https://www.wikidata.org/wiki/Q81068910".

For many of the possible properties, values can either be simple links or an inline description, depending on whether a summary is available. For a link, provide just the URL of the appropriate page as the property's value. For an inline description, use a [[WebContent]] type, and provide the url as a property of that, alongside at least a simple "[[text]]" summary of the page. It is
unlikely that a single SpecialAnnouncement will need all of the possible properties simultaneously.

We expect that in many cases the page referenced might contain more specialized structured data, e.g. contact info, [[openingHours]], [[Event]], [[FAQPage]] etc. By linking to those pages from a [[SpecialAnnouncement]] you can help make it clearer that the events are related to the situation (e.g. Coronavirus) indicated by the [[category]] property of the [[SpecialAnnouncement]].

Many [[SpecialAnnouncement]]s will relate to particular regions and to identifiable local organizations. Use [[spatialCoverage]] for the region, and [[announcementLocation]] to indicate specific [[LocalBusiness]]es and [[CivicStructure]]s. If the announcement affects both a particular region and a specific location (for example, a library closure that serves an entire region), use both [[spatialCoverage]] and [[announcementLocation]].

The [[about]] property can be used to indicate entities that are the focus of the announcement. We now recommend using [[about]] only
for representing non-location entities (e.g. a [[Course]] or a [[RadioStation]]). For places, use [[announcementLocation]] and [[spatialCoverage]]. Consumers of this markup should be aware that the initial design encouraged the use of [[about]] for locations too.

The basic content of [[SpecialAnnouncement]] is similar to that of an [RSS](https://en.wikipedia.org/wiki/RSS) or [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) feed. For publishers without such feeds, basic feed-like information can be shared by posting
[[SpecialAnnouncement]] updates in a page, e.g. using JSON-LD. For sites with Atom/RSS functionality, you can point to a feed
with the [[webFeed]] property. This can be a simple URL, or an inline [[DataFeed]] object, with [[encodingFormat]] providing
media type information, e.g. "application/rss+xml" or "application/atom+xml".
"""
    name: str | None = None
    mainEntityOfPage: str | 'CreativeWork' | None = None
    url: str | None = None
    disambiguatingDescription: str | None = None
    identifier: str | 'PropertyValue' | str | None = None
    description: str | 'TextObject' | None = None
    subjectOf: 'Event' | 'CreativeWork' | None = None
    alternateName: str | None = None
    additionalType: str | str | None = None
    potentialAction: 'Action' | None = None
    sameAs: str | None = None
    image: 'ImageObject' | str | None = None
    provider: 'Person' | 'Organization' | None = None
    aggregateRating: 'AggregateRating' | None = None
    citation: str | 'CreativeWork' | None = None
    locationCreated: 'Place' | None = None
    sdPublisher: 'Person' | 'Organization' | None = None
    thumbnail: 'ImageObject' | None = None
    accessModeSufficient: 'ItemList' | None = None
    publishingPrinciples: str | 'CreativeWork' | None = None
    inLanguage: str | 'Language' | None = None
    abstract: str | None = None
    countryOfOrigin: 'Country' | None = None
    contentLocation: 'Place' | None = None
    dateModified: datetime | date | None = None
    usageInfo: str | 'CreativeWork' | None = None
    sdDatePublished: date | None = None
    archivedAt: str | 'WebPage' | None = None
    workTranslation: 'CreativeWork' | None = None
    sdLicense: str | 'CreativeWork' | None = None
    educationalAlignment: 'AlignmentObject' | None = None
    editor: 'Person' | None = None
    license: str | 'CreativeWork' | None = None
    maintainer: 'Person' | 'Organization' | None = None
    sourceOrganization: 'Organization' | None = None
    reviews: 'Review' | None = None
    accessibilityHazard: str | None = None
    workExample: 'CreativeWork' | None = None
    pattern: 'DefinedTerm' | str | None = None
    offers: 'Offer' | 'Demand' | None = None
    hasPart: 'CreativeWork' | None = None
    keywords: 'DefinedTerm' | str | str | None = None
    exampleOfWork: 'CreativeWork' | None = None
    copyrightNotice: str | None = None
    encodingFormat: str | str | None = None
    mainEntity: 'Thing' | None = None
    editEIDR: str | str | None = None
    copyrightYear: int | float | None = None
    about: 'Thing' | None = None
    datePublished: date | datetime | None = None
    educationalLevel: str | 'DefinedTerm' | str | None = None
    accessibilityFeature: str | None = None
    materialExtent: str | 'QuantitativeValue' | None = None
    video: 'Clip' | 'VideoObject' | None = None
    funding: 'Grant' | None = None
    headline: str | None = None
    digitalSourceType: 'IPTCDigitalSourceEnumeration' | None = None
    learningResourceType: 'DefinedTerm' | str | None = None
    alternativeHeadline: str | None = None
    temporal: datetime | str | None = None
    isBasedOnUrl: str | 'CreativeWork' | 'Product' | None = None
    associatedMedia: 'MediaObject' | None = None
    commentCount: int | None = None
    dateCreated: date | datetime | None = None
    fileFormat: str | str | None = None
    teaches: 'DefinedTerm' | str | None = None
    accessibilityControl: str | None = None
    isPartOf: str | 'CreativeWork' | None = None
    accessibilityAPI: str | None = None
    contentReferenceTime: datetime | None = None
    isBasedOn: str | 'CreativeWork' | 'Product' | None = None
    creativeWorkStatus: 'DefinedTerm' | str | None = None
    award: str | None = None
    educationalUse: str | 'DefinedTerm' | None = None
    isFamilyFriendly: bool | None = None
    interactivityType: str | None = None
    publication: 'PublicationEvent' | None = None
    accountablePerson: 'Person' | None = None
    version: int | float | str | None = None
    expires: datetime | date | None = None
    awards: str | None = None
    text: str | None = None
    producer: 'Person' | 'Organization' | None = None
    thumbnailUrl: str | None = None
    copyrightHolder: 'Person' | 'Organization' | None = None
    wordCount: int | None = None
    recordedAt: 'Event' | None = None
    audience: 'Audience' | None = None
    spatial: 'Place' | None = None
    interpretedAsClaim: 'Claim' | None = None
    creditText: str | None = None
    material: 'Product' | str | str | None = None
    translator: 'Person' | 'Organization' | None = None
    character: 'Person' | None = None
    funder: 'Person' | 'Organization' | None = None
    encodings: 'MediaObject' | None = None
    contributor: 'Person' | 'Organization' | None = None
    position: int | str | None = None
    conditionsOfAccess: str | None = None
    review: 'Review' | None = None
    temporalCoverage: str | str | datetime | None = None
    mentions: 'Thing' | None = None
    interactionStatistic: 'InteractionCounter' | None = None
    schemaVersion: str | str | None = None
    acquireLicensePage: str | 'CreativeWork' | None = None
    sponsor: 'Organization' | 'Person' | None = None
    publisher: 'Organization' | 'Person' | None = None
    assesses: str | 'DefinedTerm' | None = None
    spatialCoverage: 'Place' | None = None
    size: 'QuantitativeValue' | 'DefinedTerm' | 'SizeSpecification' | str | None = None
    contentRating: str | 'Rating' | None = None
    accessMode: str | None = None
    creator: 'Person' | 'Organization' | None = None
    releasedEvent: 'PublicationEvent' | None = None
    accessibilitySummary: str | None = None
    translationOfWork: 'CreativeWork' | None = None
    publisherImprint: 'Organization' | None = None
    typicalAgeRange: str | None = None
    comment: 'Comment' | None = None
    encoding: 'MediaObject' | None = None
    discussionUrl: str | None = None
    timeRequired: 'Duration' | None = None
    isAccessibleForFree: bool | None = None
    audio: 'AudioObject' | 'MusicRecording' | 'Clip' | None = None
    correction: 'CorrectionComment' | str | str | None = None
    author: 'Person' | 'Organization' | None = None
    genre: str | str | None = None
    webFeed: str | 'DataFeed' | None = None
    datePosted: datetime | date | None = None
    schoolClosuresInfo: str | 'WebContent' | None = None
    diseaseSpreadStatistics: 'Dataset' | str | 'Observation' | 'WebContent' | None = None
    diseasePreventionInfo: str | 'WebContent' | None = None
    category: 'CategoryCode' | str | 'Thing' | 'PhysicalActivityCategory' | str | None = None
    newsUpdatesAndGuidelines: str | 'WebContent' | None = None
    gettingTestedInfo: 'WebContent' | str | None = None
    announcementLocation: 'LocalBusiness' | 'CivicStructure' | None = None
    publicTransportClosuresInfo: 'WebContent' | str | None = None
    quarantineGuidelines: str | 'WebContent' | None = None
    governmentBenefitsInfo: 'GovernmentService' | None = None
    travelBans: str | 'WebContent' | None = None

==> msgspec_schemaorg-0.1.5-py3-none-any.whl: msgspec_schemaorg/models/creativework/SpecialAnnouncement.py <==
from __future__ import annotations
from msgspec import Struct, field
from msgspec_schemaorg.models.creativework.CreativeWork import CreativeWork
from msgspec_schemaorg.utils import parse_iso8601
from msgspec_schemaorg.utils import URL
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from msgspec_schemaorg.models.creativework.DataFeed import DataFeed
    from msgspec_schemaorg.models.creativework.Dataset import Dataset
    from msgspec_schemaorg.models.creativework.WebContent import WebContent
    from msgspec_schemaorg.models.intangible.CategoryCode import CategoryCode
    from msgspec_schemaorg.models.intangible.GovernmentService import GovernmentService
    from msgspec_schemaorg.models.intangible.Observation import Observation
    from msgspec_schemaorg.models.intangible.PhysicalActivityCategory import PhysicalActivityCategory
    from msgspec_schemaorg.models.place.CivicStructure import CivicStructure
    from msgspec_schemaorg.models.place.LocalBusiness import LocalBusiness
    from msgspec_schemaorg.models.thing.Thing import Thing
from datetime import date, datetime
from typing import Optional, Union, Dict, List, Any


class SpecialAnnouncement(CreativeWork):
    """A SpecialAnnouncement combines a simple date-stamped textual information update
      with contextualized Web links and other structured data.  It represents an information update made by a
      locally-oriented organization, for example schools, pharmacies, healthcare providers,  community groups, police,
      local government.

For work in progress guidelines on Coronavirus-related markup see [this doc](https://docs.google.com/document/d/14ikaGCKxo50rRM7nvKSlbUpjyIk2WMQd3IkB1lItlrM/edit#).

The motivating scenario for SpecialAnnouncement is the [Coronavirus pandemic](https://en.wikipedia.org/wiki/2019%E2%80%9320_coronavirus_pandemic), and the initial vocabulary is oriented to this urgent situation. Schema.org
expect to improve the markup iteratively as it is deployed and as feedback emerges from use. In addition to our
usual [Github entry](https://github.com/schemaorg/schemaorg/issues/2490), feedback comments can also be provided in [this document](https://docs.google.com/document/d/1fpdFFxk8s87CWwACs53SGkYv3aafSxz_DTtOQxMrBJQ/edit#).


While this schema is designed to communicate urgent crisis-related information, it is not the same as an emergency warning technology like [CAP](https://en.wikipedia.org/wiki/Common_Alerting_Protocol), although there may be overlaps. The intent is to cover
the kinds of everyday practical information being posted to existing websites during an emergency situation.

Several kinds of information can be provided:

We encourage the provision of "name", "text", "datePosted", "expires" (if appropriate), "category" and
"url" as a simple baseline. It is important to provide a value for "category" where possible, most ideally as a well known
URL from Wikipedia or Wikidata. In the case of the 2019-2020 Coronavirus pandemic, this should be "https://en.wikipedia.org/w/index.php?title=2019-20\\_coronavirus\\_pandemic" or "https://www.wikidata.org/wiki/Q81068910".

For many of the possible properties, values can either be simple links or an inline description, depending on whether a summary is available. For a link, provide just the URL of the appropriate page as the property's value. For an inline description, use a [[WebContent]] type, and provide the url as a property of that, alongside at least a simple "[[text]]" summary of the page. It is
unlikely that a single SpecialAnnouncement will need all of the possible properties simultaneously.

We expect that in many cases the page referenced might contain more specialized structured data, e.g. contact info, [[openingHours]], [[Event]], [[FAQPage]] etc. By linking to those pages from a [[SpecialAnnouncement]] you can help make it clearer that the events are related to the situation (e.g. Coronavirus) indicated by the [[category]] property of the [[SpecialAnnouncement]].

Many [[SpecialAnnouncement]]s will relate to particular regions and to identifiable local organizations. Use [[spatialCoverage]] for the region, and [[announcementLocation]] to indicate specific [[LocalBusiness]]es and [[CivicStructure]]s. If the announcement affects both a particular region and a specific location (for example, a library closure that serves an entire region), use both [[spatialCoverage]] and [[announcementLocation]].

The [[about]] property can be used to indicate entities that are the focus of the announcement. We now recommend using [[about]] only
for representing non-location entities (e.g. a [[Course]] or a [[RadioStation]]). For places, use [[announcementLocation]] and [[spatialCoverage]]. Consumers of this markup should be aware that the initial design encouraged the use of [[about]] for locations too.

The basic content of [[SpecialAnnouncement]] is similar to that of an [RSS](https://en.wikipedia.org/wiki/RSS) or [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) feed. For publishers without such feeds, basic feed-like information can be shared by posting
[[SpecialAnnouncement]] updates in a page, e.g. using JSON-LD. For sites with Atom/RSS functionality, you can point to a feed
with the [[webFeed]] property. This can be a simple URL, or an inline [[DataFeed]] object, with [[encodingFormat]] providing
media type information, e.g. "application/rss+xml" or "application/atom+xml".
"""
    type: str = field(default_factory=lambda: "SpecialAnnouncement", name="@type")
    webFeed: Union[List[Union['URL', 'DataFeed']], Union['URL', 'DataFeed'], None] = None
    datePosted: Union[List[Union[datetime, date]], Union[datetime, date], None] = None
    schoolClosuresInfo: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
    diseaseSpreadStatistics: Union[List[Union['URL', 'Dataset', 'Observation', 'WebContent']], Union['URL', 'Dataset', 'Observation', 'WebContent'], None] = None
    diseasePreventionInfo: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
    category: Union[List[Union['URL', str, 'CategoryCode', 'Thing', 'PhysicalActivityCategory']], Union['URL', str, 'CategoryCode', 'Thing', 'PhysicalActivityCategory'], None] = None
    newsUpdatesAndGuidelines: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
    gettingTestedInfo: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
    announcementLocation: Union[List[Union['LocalBusiness', 'CivicStructure']], Union['LocalBusiness', 'CivicStructure'], None] = None
    publicTransportClosuresInfo: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
    quarantineGuidelines: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
    governmentBenefitsInfo: Union[List['GovernmentService'], 'GovernmentService', None] = None
    travelBans: Union[List[Union['URL', 'WebContent']], Union['URL', 'WebContent'], None] = None
